@@ -5,6 +5,7 @@
 */
 
 #include "debugmodel.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KLocalizedString>
 
@@ -22,18 +23,18 @@ DebugModel::DebugModel(QObject *parent)
 
 DebugModel::~DebugModel() = default;
 
-QString DebugModel::displaySender(const QString &identifer) const
+QString DebugModel::displaySender(const QString &identifier) const
 {
-    if (mSenderCache[identifer].isEmpty()) {
-        return identifer;
+    if (mSenderCache[identifier].isEmpty()) {
+        return identifier;
     } else {
-        return QString(mSenderCache[identifer] + QStringLiteral(" (") + identifer + QStringLiteral(")"));
+        return QString(mSenderCache[identifier] + u" ("_s + identifier + u")"_s);
     }
 }
 
 QString DebugModel::cacheString(const QString &str, QMap<QString, QString> &cache, QStandardItemModel *model)
 {
-    auto pos = str.lastIndexOf(QLatin1Char('('));
+    auto pos = str.lastIndexOf(u'(');
     auto identifier = str;
     QString name;
     if (pos != -1) {
@@ -76,16 +77,16 @@ bool DebugModel::removeRows(int row, int count, const QModelIndex &parent)
     QList<QString> toDelete;
 
     // find elements that needs to be deleted.
-    for (const auto &identifer : mSenderCache.keys()) {
+    for (const auto &identifier : mSenderCache.keys()) {
         bool found = false;
         for (const auto &msg : std::as_const(mMessages)) {
-            if (msg.sender == identifer) {
+            if (msg.sender == identifier) {
                 found = true;
                 break;
             }
         }
         if (!found) {
-            toDelete.push_back(identifer);
+            toDelete.push_back(identifier);
         }
     }
 
@@ -162,9 +163,9 @@ QVariant DebugModel::data(const QModelIndex &index, int role) const
         case DirectionColumn:
             switch (message.direction) {
             case ClientToServer:
-                return QStringLiteral("<-");
+                return u"<-"_s;
             case ServerToClient:
-                return QStringLiteral("->");
+                return u"->"_s;
             }
             return {};
         case MessageColumn:
