@@ -84,11 +84,12 @@ struct Restorer {
         }                                                                                                                                                      \
     }
 
-template<typename Op, typename Config> static void processWidgets(QWidget *widget, Config config)
+template<typename Op, typename Config>
+static void processWidgets(QWidget *widget, Config config)
 {
     QList<QWidget *> widgets = widget->findChildren<QWidget *>();
     widgets << widget;
-    for (QWidget *w : qAsConst(widgets)) {
+    for (QWidget *w : std::as_const(widgets)) {
         if (w->objectName().isEmpty()) {
             continue;
         }
